const workspace = Blockly.inject(
  'blocklyMain',
  {
    media: './node_modules/blockly/media',
    toolbox: toolbox,
    grid: {
      spacing: 10,
      length: 1,
      colour: '#ccc',
      snap: true,
    },
    move: {
      scrollbars: true,
      drag: true,
      wheel: true,
    },
    zoom: {
      controls: true,
    },
    plugins: {
      [Blockly.registry.Type.CONNECTION_CHECKER] : 'FoxcubbyConnectionChecker',
    },
  }
);

let changeDate = new Date();

new ResizeObserver(
  function () {
    Blockly.svgResize(workspace);
  }
).observe(
  document.getElementById('blocklyMain')
);

function setDisabledState() {
  document.getElementById('undoButton').disabled = workspace.getUndoStack().length === 0;
  document.getElementById('redoButton').disabled = workspace.getRedoStack().length === 0;
};

function rememberWorkspace() {
  localStorage.setItem(
    'workspace',
    JSON.stringify(
      Blockly.serialization.workspaces.save(workspace)
    )
  );
}

function rememberName() {
  localStorage.setItem(
    'name',
    document.getElementById('name').value
  );
}

function rememberAuthor() {
  localStorage.setItem(
    'author',
    document.getElementById('author').value
  );
}

function trapFocus (event) {
  if (event === undefined || !document.getElementById('runContainer').contains(event.target)) {
    document.querySelector('#runMain').focus();
  }
};

function closeModal() {
  document.removeEventListener('focus', trapFocus, true);

  let runContainer = document.getElementById('runContainer');
  runContainer.innerHTML = '';
  runContainer.outerHTML = runContainer.outerHTML;
}

async function openModal(func) {
  Blockly.getSelected()?.unselect();
  
  document.getElementById('runContainer').innerHTML = '<div id="runMain" class="container__main area" tabindex="-1"></div><div id="runButtons" class="container__buttons"></div>';

  document.addEventListener('focus', trapFocus, true);
  
  trapFocus();
  
  newButton('', 'closeButton')
    .setText('Schließen')
    .setImage(openmojiColor['274C'])
    .onClick(closeModal);

  await pauseMilliseconds(100);
  await func();
}

document.getElementById('name').addEventListener('input', rememberName);

document.getElementById('author').addEventListener('input', rememberAuthor);

const blocklyButtons = elementCollection(document.querySelectorAll('#blocklyButtons'));
const jsButtons = elementCollection(document.querySelectorAll('#jsButtons'));

newButton('', 'newButton', blocklyButtons)
  .setText('Neu')
  .setImage(openmojiBlack['1F4C4'])
  .onClick(() => {
    Blockly.serialization.workspaces.load(
      {},
      workspace
    );
    rememberWorkspace();

    document.getElementById('name').value = '';
    rememberName();

    changeDate = new Date();

    setDisabledState();
  });

newButton('', 'loadButton', blocklyButtons)
  .setText('Laden')
  .setImage(openmojiColor['1F4E4'])
  .onClick(() => {
    const fileInput = document.createElement('input');
    fileInput.type = 'file';
    fileInput.accept = '.foxcubby';
    fileInput.style.display = 'none';

    fileInput.addEventListener(
      'input',
      function () {
        const fileReader = new FileReader();
        fileReader.addEventListener(
          'load',
          function () {
            let fileContent = JSON.parse(fileReader.result);
            blocklyButtons.firstItem().removeChild(fileInput);

            Blockly.serialization.workspaces.load(
              fileContent.workspace,
              workspace
            );
            rememberWorkspace();

            document.getElementById('name').value = fileContent.name;
            rememberName();

            document.getElementById('author').value = fileContent.author;
            rememberAuthor();

            changeDate = new Date();

            setDisabledState();
          }
        );
        fileReader.readAsText(fileInput.files.item(0));
      }
    );

    blocklyButtons.firstItem().insertBefore(fileInput, blocklyButtons.firstItem().firstChild);
    fileInput.click();
  });

newButton('', 'saveButton', blocklyButtons)
  .setText('Speichern')
  .setImage(openmojiColor['1F4E5'])
  .onClick(() => {
    const pad0 = (value) => (value + '').padStart(2, '0');
    const formattedDate = changeDate.getFullYear() + '-' + pad0(changeDate.getMonth() + 1) + '-' + pad0(changeDate.getDate());
    const formattedTime = pad0(changeDate.getHours()) + pad0(changeDate.getMinutes()) + pad0(changeDate.getSeconds());
    const name = document.getElementById('name').value;
    const author = document.getElementById('author').value;
    const fileName = name.toLowerCase().replace(/[^a-z0-9äöüß]+/g, '-') + '-' + formattedDate + '-' + formattedTime + '.foxcubby';
    
    const text = JSON.stringify(
      {
        foxcubbyVersion: 1,
        name: name,
        author: author,
        workspace: Blockly.serialization.workspaces.save(workspace),
        code: Blockly.JavaScript.workspaceToCode(workspace),
      }
    );

    const downloadLink = document.createElement('a');
    downloadLink.style.display = 'none';
    downloadLink.href = 'data:text/plain;charset=utf-8,' + encodeURIComponent(text);
    downloadLink.download = fileName;

    blocklyButtons.firstItem().insertBefore(downloadLink, blocklyButtons.firstItem().firstChild);

    downloadLink.click();

    blocklyButtons.firstItem().removeChild(downloadLink);
  });

newButton('', 'undoButton', blocklyButtons)
  .setText('Rück­gängig')
  .setImage(openmojiColor['21A9'])
  .onClick(() => {
    workspace.undo();
    setDisabledState();
  });

newButton('', 'redoButton', blocklyButtons)
  .setText('Wieder­herstellen')
  .setImage(openmojiColor['21AA'])
  .onClick(() => {
    workspace.undo(true);
    setDisabledState();
  });

newButton('', 'runButton', jsButtons)
  .setText('Ausführen')
  .setImage(openmojiBlack['25B6'])
  .onClick(async () => {
    await openModal(async () => {
      Blockly.JavaScript.addReservedWords('newArea,findArea,newButton');
      try {
        eval(`(async () => {` + Blockly.JavaScript.workspaceToCode(workspace) + `})();`);
      } catch (error) {
        console.log(error);
      }
    });
  });

newButton('', 'exportButton', jsButtons)
  .setText('Exportieren')
  .setImage(openmojiBlack['E25C'])
  .onClick(() => {
    const pad0 = (value) => (value + '').padStart(2, '0');
    const formattedDate = changeDate.getFullYear() + '-' + pad0(changeDate.getMonth() + 1) + '-' + pad0(changeDate.getDate());
    const formattedTime = pad0(changeDate.getHours()) + pad0(changeDate.getMinutes()) + pad0(changeDate.getSeconds());
    const name = document.getElementById('name').value;
    const author = document.getElementById('author').value;
    const fileName = name.toLowerCase().replace(/[^a-z0-9äöüß]+/g, '-') + '-' + formattedDate + '-' + formattedTime + '.html';
    
    let text = Esqeypr.html`<!DOCTYPE html><meta charset="utf-8">
<title>${name}</title>
<script>
  async function run () {
    ` + Blockly.JavaScript.workspaceToCode(workspace) + Esqeypr.html`
  }



` + document.getElementById('runJs').innerHTML + Esqeypr.html`</script>
<style>` + document.getElementById('runCss').innerHTML + Esqeypr.html`</style>

<body id="runContainer" class="container" role="alertdialog" aria-modal="true">
  <div id="runMain" class="container__main area"></div>
  <div id="runButtons" class="container__buttons"></div>
</body>

<script>
  newButton('', 'infoButton').setText('Info').setImage(\`` + openmojiBlack['2139'] + Esqeypr.html`\`).onClick(() => {
    let infoContainer = document.createElement('div');
    infoContainer.classList.add('container');
    infoContainer.id = 'infoContainer';
    infoContainer.innerHTML = '<div id="infoMain" class="container__main area" tabindex="-1"><div class="area__child--text"><h1>${name}</h1><p>Programmiert von ${author}.</p><p>Programmierwerkzeug: Foxcubby (entwickelt von Olaf Schmidt-Wischhöfer unter Verwendung von <a href="https://developers.google.com/blockly" target="_blank" rel="noreferrer">Blockly</a>).</p><p>All emojis designed by <a href="openmoji.org">OpenMoji</a> – the open-source emoji and icon project (Emoji License: <a href="https://creativecommons.org/licenses/by-sa/4.0/">CC BY-SA 4.0</a>).</p></div></div><div id="infoButtons" class="container__buttons"></div>';
    document.body.appendChild(infoContainer);

    let infoMain = document.querySelector('#infoMain');
    infoMain.focus();
    document.addEventListener('focus', (event) => {if (!infoContainer.contains(event.target)) {infoMain.focus();}}, true);

    newButton('', 'closeButton', elementCollection(document.querySelectorAll('#infoButtons'))).setText('Schließen').setImage(\`` + openmojiColor['274C'] + Esqeypr.html`\`).onClick(() => {infoContainer.remove();});
  });

  setTimeout(run, 0);
</script>
`;
    
    const downloadLink = document.createElement('a');
    downloadLink.style.display = 'none';
    downloadLink.href = 'data:text/plain;charset=utf-8,' + encodeURIComponent(text);
    downloadLink.download = fileName;

    jsButtons.firstItem().insertBefore(downloadLink, jsButtons.firstItem().firstChild);

    downloadLink.click();

    jsButtons.firstItem().removeChild(downloadLink);
  });

newButton('', 'infoButton', jsButtons)
  .setText('Info')
  .setImage(openmojiColor['1F98A'])
  .onClick(async () => {
    await openModal(async () => {
      newArea('rectangle')
      .setProperty('height', 100)
      .setHTML('<h1>Foxcubby – Web-Programmierung mit Blockly</h1><p>Entwickelt von Olaf Schmidt-Wischhöfer unter Verwendung von <a href="https://developers.google.com/blockly" target="_blank" rel="noreferrer">Blockly</a>.</p><p>All emojis designed by <a href="openmoji.org">OpenMoji</a> – the open-source emoji and icon project (Emoji license: <a href="https://creativecommons.org/licenses/by-sa/4.0/">CC BY-SA 4.0</a>)</p>')
    });
  });

workspace.addChangeListener(
  function () {
    changeDate = new Date();

    setDisabledState();

    rememberWorkspace();
    
    document.getElementById('jsMain').textContent = Blockly.JavaScript.workspaceToCode(workspace);
  }
);

try {
  Blockly.serialization.workspaces.load(
    JSON.parse(localStorage.getItem('workspace') ?? '[]'),
    workspace
  );
} catch(error) {
  console.log(error);
  localStorage.removeItem('workspace');
}

document.getElementById('name').value = localStorage.getItem('name') ?? 'programm';
document.getElementById('author').value = localStorage.getItem('author') ?? '';

setDisabledState();
