function statementListUsesAsync(block, name) {
  let childBlock = block.getInputTargetBlock(name);

  while (childBlock !== null) {
    if (blockUsesAsync(childBlock)) {
      return true;
    }
    childBlock = childBlock.getNextBlock();
  }
  return false;
}

function blockUsesAsync(block) {
  if (block === null) {
    return false;
  }
  
  let childBlock;

  switch (block.type) {
    case 'wait':
      return true;
    case 'procedures_callnoreturn':
    case 'procedures_callreturn':
      return blockUsesAsync(Blockly.Procedures.getDefinition(block.getFieldValue('NAME'), workspace));
    case 'procedures_defnoreturn':
    case 'procedures_defreturn':
      return statementListUsesAsync(block, 'STACK');
    case 'controls_repeat_ext':
    case 'controls_repeat':
    case 'controls_whileUntil':
    case 'controls_for':
    case 'controls_forEach':
      return statementListUsesAsync(block, 'DO');
    case 'controls_if':
      let n = 0;
      while (block.getInput('DO' + n)) {
        if (statementListUsesAsync(block, 'DO' + n)) {
          return true;
        }
        n++;
      }
      return statementListUsesAsync(block, 'ELSE');
    default:
      return false;
  }

  while (childBlock !== null) {
    if (usesAsync(childBlock)) {
      return true;
    }
    childBlock = childBlock.getNextBlock();
  }
  return false;
}

Blockly.JavaScript['element_new_area'] = function(block) {
  const shape = block.getFieldValue('shape');
  const name = Blockly.JavaScript.valueToCode(block, 'name', Blockly.JavaScript.ORDER_COMMA);
  const methods = Blockly.JavaScript.statementToCode(block, 'methods');
  let code = `newArea('${shape}'${name === '' ? '' : ', '}${name})`;
  
  if (shape === 'image') {  
    const image = Blockly.JavaScript.valueToCode(block, 'image',  Blockly.JavaScript.ORDER_ATOMIC);
    if (image !== '') {
      code += `\n${Blockly.JavaScript.INDENT}.setImage(${image})`;
    }
  }

  code += methods.replace(/^  /g, '');
  
  return code + `;\n\n`;
};

Blockly.JavaScript['element_new_button'] = function(block) {
  const name = Blockly.JavaScript.valueToCode(block, 'name', Blockly.JavaScript.ORDER_COMMA);
  const methods = Blockly.JavaScript.statementToCode(block, 'methods');
  
  return `newButton(${name})${methods.replace(/^  /g, '')};\n\n`;
};

Blockly.JavaScript['element_find'] = function(block) {
  const name = Blockly.JavaScript.valueToCode(block, 'name', Blockly.JavaScript.ORDER_COMMA);
  const methods = Blockly.JavaScript.statementToCode(block, 'methods');
  
  return `findElements(${name})${methods.replace(/^  /g, '')};\n\n`;
};

Blockly.JavaScript['element_method_change_property'] = function(block) {
  const value = Blockly.JavaScript.valueToCode(block, 'value', Blockly.JavaScript.ORDER_COMMA);
  const property = block.getFieldValue('property');

  if (block.getPreviousBlock() === null || value === '') {
    return '';
  }
  return `\n.setProperty('${property}', ${value})`;
};

Blockly.JavaScript['element_method_move_area'] = function(block) {
  if (block.getPreviousBlock() === null) {
    return '';
  }

  let name;

  switch (block.getFieldValue('target')) {
    case 'begin':
      return `\n.moveToBegin()`;
    case 'end':
      return `\n.moveToEnd()`;
    case 'first-in-area':
      name = Blockly.JavaScript.valueToCode(block, 'name', Blockly.JavaScript.ORDER_NONE);
      return name === '' ? '' : `\n.moveToBegin(findElements(${name}))`;
    case 'last-in-area':
      name = Blockly.JavaScript.valueToCode(block, 'name', Blockly.JavaScript.ORDER_NONE);
      return name === '' ? '' : `\n.moveToEnd(findElements(${name}))`;
    case 'before-area':
      name = Blockly.JavaScript.valueToCode(block, 'name', Blockly.JavaScript.ORDER_NONE);
      return name === '' ? '' : `\n.moveBefore(findElements(${name}))`;
    case 'after-area':
      name = Blockly.JavaScript.valueToCode(block, 'name', Blockly.JavaScript.ORDER_NONE);
      return name === '' ? '' : `\n.moveAfter(findElements(${name}))`;
  }
};

Blockly.JavaScript['element_method_delete'] = function(block) {
  if (block.getPreviousBlock() === null) {
    return '';
  }

  return `\n.remove()`;
};

Blockly.JavaScript['element_method_change_text'] = function(block) {
  if (block.getPreviousBlock() === null) {
    return '';
  }

  const text = Blockly.JavaScript.valueToCode(block, 'text', Blockly.JavaScript.ORDER_NONE);
  return text === '' ? '' : `\n.setText(${text})`;
};

Blockly.JavaScript['element_method_change_image'] = function(block) {
  if (block.getPreviousBlock() === null) {
    return '';
  }

  const image = Blockly.JavaScript.valueToCode(block, 'image', Blockly.JavaScript.ORDER_NONE) || `''`;
  return `\n.setImage(${image})`;
};

Blockly.JavaScript['element_method_event_click'] = function(block) {
  if (block.getPreviousBlock() === null) {
    return '';
  }

  let code = '';
  const methods = Blockly.JavaScript.statementToCode(block, 'methods');
  if (methods !== '') {
    code += Blockly.JavaScript.prefixLines('element' + methods.trim() + ';\n', Blockly.JavaScript.INDENT);
  }
  code += Blockly.JavaScript.statementToCode(block, 'statements');

  return `\n.onClick(${statementListUsesAsync(block, 'statements') ? 'async ' : ''}element => {\n${code}})`;
}; 

Blockly.JavaScript['event_key'] = function(block) {
  let key = block.getFieldValue('key');

  if (key === 'Other') {
    key = Blockly.JavaScript.valueToCode(block, 'text', Blockly.JavaScript.ORDER_COMMA) || `''`;
  } else {
    key =  `'${key}'`;
  }

  let code = Blockly.JavaScript.statementToCode(block, 'statements');
  code += `\n${Blockly.JavaScript.INDENT}event.preventDefault();\n`;

  return `onKey(${key}, ${statementListUsesAsync(block, 'statements') ? 'async ' : ''}() => {\n${code}});\n`;
}; 

Object.keys(openmojiTopics).forEach((topic) => {
  Blockly.JavaScript['image_' + topic] = function(block) {
    const image = block.getFieldValue('image');
    const xml = openmojiColor[image].replace(/>[ \n\r]+</g, '><').trim();
    
    const functionName = Blockly.JavaScript.provideFunction_(
      'getImage' + image,
      `function ${Blockly.JavaScript.FUNCTION_NAME_PLACEHOLDER_} () {\n  return \`${xml}\`;\n}`
    );
    return [`${functionName}()`, Blockly.JavaScript.ORDER_ATOMIC];
  };
});

Blockly.JavaScript['colour_transparent'] = function(block) {
  return [`'transparent'`, Blockly.JavaScript.ORDER_ATOMIC];
};

Blockly.JavaScript['element_get_property_as_number'] = function(block) {
  const name = Blockly.JavaScript.valueToCode(block, 'name', Blockly.JavaScript.ORDER_ATOMIC);
  const property = block.getFieldValue('property');

  return [`findElements(${name}).getPropertyValueAsNumber('${property}')`, Blockly.JavaScript.ORDER_MEMBER];
};

Blockly.JavaScript['element_get_property_as_colour'] = function(block) {
  const name = Blockly.JavaScript.valueToCode(block, 'name', Blockly.JavaScript.ORDER_ATOMIC);
  const property = block.getFieldValue('property');

  return [`findElements(${name}).getPropertyValue('${property}')`, Blockly.JavaScript.ORDER_MEMBER];
};

Blockly.JavaScript['element_get_text'] = function(block) {
  const name = Blockly.JavaScript.valueToCode(block, 'name', Blockly.JavaScript.ORDER_ATOMIC);

  return [`findElements(${name}).getText()`, Blockly.JavaScript.ORDER_MEMBER];
};

Blockly.JavaScript['element_get_image'] = function(block) {
  const name = Blockly.JavaScript.valueToCode(block, 'name', Blockly.JavaScript.ORDER_ATOMIC);

  return [`findElements(${name}).getImage()`, Blockly.JavaScript.ORDER_MEMBER];
};

Blockly.JavaScript['event_timeout'] = function(block) {
  const seconds = Blockly.JavaScript.valueToCode(block, 'seconds', Blockly.JavaScript.ORDER_MULTIPLICATION) || `0`;
  const code = Blockly.JavaScript.prefixLines(
    `${statementListUsesAsync(block, 'statements') ? 'async ' : ''}() => {\n` + Blockly.JavaScript.statementToCode(block, 'statements') + `},\n${seconds} * 1000\n`,
    Blockly.JavaScript.INDENT
  );

  return `setTimeout(\n ${code});\n`;
};

Blockly.JavaScript['event_interval'] = function(block) {
  const seconds = Blockly.JavaScript.valueToCode(block, 'seconds', Blockly.JavaScript.ORDER_MULTIPLICATION) || `0`;
  const code = Blockly.JavaScript.prefixLines(
    `${statementListUsesAsync(block, 'statements') ? 'async ' : ''}() => {\n` + Blockly.JavaScript.statementToCode(block, 'statements') + `},\n${seconds} * 1000\n`,
    Blockly.JavaScript.INDENT
  );

  return `setInterval(\n${code});\n`;
};

Blockly.JavaScript['wait'] = function(block) {
  const seconds = Blockly.JavaScript.valueToCode(block, 'seconds', Blockly.JavaScript.ORDER_MULTIPLICATION) || `0`;
  return `await pauseMilliseconds(${seconds} * 1000);\n`;
};

const orginalProceduresCallreturn = Blockly.JavaScript['procedures_callreturn'];
Blockly.JavaScript['procedures_callreturn'] = function (block) {
  const codeAndOrder = orginalProceduresCallreturn(block);

  if (!blockUsesAsync(block)) {
    return codeAndOrder;
  }

  const order = codeAndOrder.pop();
  let code = codeAndOrder.pop();
  
  if (order > Blockly.JavaScript.ORDER_AWAIT) {
    code = `(${code})`;
  }

  return [`await ` + code, Blockly.JavaScript.ORDER_AWAIT]
}

const originalProceduresDefreturn = Blockly.JavaScript['procedures_defreturn'];
Blockly.JavaScript['procedures_defreturn'] = function (block) {
  originalProceduresDefreturn(block);
  
  if (blockUsesAsync(block)) {
    const funcName = Blockly.JavaScript.nameDB_.getName(block.getFieldValue('NAME'), Blockly.Names.NameType.PROCEDURE);
    
    if (Blockly.JavaScript.definitions_['%' + funcName].includes('await ')) {
      Blockly.JavaScript.definitions_['%' + funcName] = Blockly.JavaScript.definitions_['%' + funcName].replace(/\nfunction /g, '\nasync function ');
    }
  }

  return null;
}

Blockly.JavaScript['procedures_defnoreturn'] = Blockly.JavaScript['procedures_defreturn'];
